Documentation
¶
Overview ¶
Package gover provides some simple public version variables.
Index ¶
Constants ¶
This section is empty.
Variables ¶
Some variables
var TextTemplate = `` /* 143-byte string literal not displayed */
TextTemplate is used to format the text version, which is a go text template.
Functions ¶
func GetBuildTime ¶
GetBuildTime converts the string BuildTime to time.Time.
func GetElapsedTime ¶ added in v0.2.0
GetElapsedTime returns the elapsed time since the application starts.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.